FileLogFormat enum

The format used when writing log records to file.

Inheritance
Available extensions

Values

text → const FileLogFormat

Human-readable single-line format: 2026-03-28T14:23:01.456 [INFO] [auth] User signed in

json → const FileLogFormat

One JSON object per line (NDJSON), suitable for machine parsing: {"level":"INFO","timestamp":"2026-03-28T14:23:01.456","message":"..."}

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FileLogFormat>
A constant List of the values in this enum, in order of their declaration.