flush method
Flush all buffered records to disk immediately.
Call this before app shutdown to ensure no records are lost.
Implementation
Future<void> flush() => _flush();
Flush all buffered records to disk immediately.
Call this before app shutdown to ensure no records are lost.
Future<void> flush() => _flush();